﻿using System;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Windows.Forms;

using Steema.TeeChart.Drawing;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : Form
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            Text = "Graphics3D 클래스 : Ellipse 메소드 사용하기";

            this.ellipseAngleTrackBar.Minimum = 0;
            this.ellipseAngleTrackBar.Value   = 0;
            this.ellipseAngleTrackBar.Maximum = 360;

            this.tChart.Aspect.View3D         = true;
            this.tChart.Aspect.Orthogonal     = false;
            this.tChart.Aspect.Chart3DPercent = 65;
            this.tChart.Aspect.Perspective    = 70;
            this.tChart.Panel.Pen             = new ChartPen(Color.Black);

            this.ellipseAngleTrackBar.ValueChanged += ellipseAngleTrackBar_ValueChanged;
            this.tChart.AfterDraw                  += tChart_AfterDraw;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 타원 각도 트랙바 값 변경시 처리하기 - ellipseAngleTrackBar_ValueChanged(sender, e)

        /// <summary>
        /// 타원 각도 트랙바 값 변경시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void ellipseAngleTrackBar_ValueChanged(object sender, EventArgs e)
        {
            this.tChart.Invalidate();
        }

        #endregion
        #region TChart 클래스 그리기 후 처리하기 - tChart_AfterDraw(sender, graphics3D)

        /// <summary>
        /// TChart 클래스 그리기 후 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="graphics3D">그래픽스 3D</param>
        private void tChart_AfterDraw(object sender, Graphics3D graphics3D)
        {
            graphics3D.Pen.Style     = DashStyle.Solid;
            graphics3D.Pen.Color     = Color.Blue;
            graphics3D.Brush.Color   = Color.Azure;
            graphics3D.Brush.Visible = true;

            graphics3D.Ellipse(50, 90, 250, 160, 0, this.ellipseAngleTrackBar.Value);
        }

        #endregion
    }
}